[Scummvm-cvs-logs] SF.net SVN: scummvm:[39753] scummvm/trunk/engines/agos

Kirben at users.sourceforge.net Kirben at users.sourceforge.net
Mon Mar 30 10:31:30 CEST 2009


Revision: 39753
          http://scummvm.svn.sourceforge.net/scummvm/?rev=39753&view=rev
Author:   Kirben
Date:     2009-03-30 08:31:30 +0000 (Mon, 30 Mar 2009)

Log Message:
-----------
Add GF_EGA feature flag for PN, to allow easier support of PC VGA version in future.

Modified Paths:
--------------
    scummvm/trunk/engines/agos/detection_tables.h
    scummvm/trunk/engines/agos/intern.h
    scummvm/trunk/engines/agos/pn.cpp
    scummvm/trunk/engines/agos/vga.cpp

Modified: scummvm/trunk/engines/agos/detection_tables.h
===================================================================
--- scummvm/trunk/engines/agos/intern.h	2009-03-30 08:09:02 UTC (rev 39752)
+++ scummvm/trunk/engines/agos/intern.h	2009-03-30 08:31:30 UTC (rev 39753)
@@ -252,8 +252,9 @@
 	GF_CRUNCHED_GAMEPC = 1 << 3,
 	GF_ZLIBCOMP        = 1 << 4,
 	GF_32COLOR         = 1 << 5,
-	GF_PLANAR          = 1 << 6,
-	GF_DEMO            = 1 << 7
+	GF_EGA             = 1 << 6,
+	GF_PLANAR          = 1 << 7,
+	GF_DEMO            = 1 << 8
 };
 
 enum GameFileTypes {

Modified: scummvm/trunk/engines/agos/pn.cpp
===================================================================
--- scummvm/trunk/engines/agos/pn.cpp	2009-03-30 08:09:02 UTC (rev 39752)
+++ scummvm/trunk/engines/agos/pn.cpp	2009-03-30 08:31:30 UTC (rev 39753)
@@ -128,7 +128,7 @@
 
 	addVgaEvent(_frameCount, ANIMATE_INT, NULL, 0, 0);
 
-	if (getPlatform() == Common::kPlatformPC) {
+	if (getFeatures() & GF_EGA) {
 		// Set EGA Palette
 		for (int i = 0; i < 16; i++) {
 			_displayPalette[i * 4 + 0] = egaPalette[i * 3 + 0];

Modified: scummvm/trunk/engines/agos/vga.cpp
===================================================================
--- scummvm/trunk/engines/agos/vga.cpp	2009-03-30 08:09:02 UTC (rev 39752)
+++ scummvm/trunk/engines/agos/vga.cpp	2009-03-30 08:31:30 UTC (rev 39753)
@@ -924,8 +924,8 @@
 
 	b = vcReadNextWord();
 
-	// PC version of Personal Nightmare uses standard EGA palette
-	if (getGameType() == GType_PN && getPlatform() == Common::kPlatformPC)
+	// PC EGA version of Personal Nightmare uses standard EGA palette
+	if (getGameType() == GType_PN && (getFeatures() & GF_EGA))
 		return;
 
 	num = 16;
@@ -1298,8 +1298,8 @@
 	uint16 offs = vcReadNextWord();
 	uint16 color = vcReadNextWord();
 
-	// PC version of Personal Nightmare uses standard EGA palette
-	if (getGameType() == GType_PN && getPlatform() == Common::kPlatformPC)
+	// PC EGA version of Personal Nightmare uses standard EGA palette
+	if (getGameType() == GType_PN && (getFeatures() & GF_EGA))
 		return;
 
 	byte *palptr = _displayPalette + offs * 4;


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list
--- scummvm/trunk/engines/agos/detection_tables.h	2009-03-30 08:09:02 UTC (rev 39752)
+++ scummvm/trunk/engines/agos/detection_tables.h	2009-03-30 08:31:30 UTC (rev 39753)
@@ -92,7 +92,7 @@
 		GF_OLD_BUNDLE | GF_CRUNCHED | GF_PLANAR
 	},
 
 	// Personal Nightmare 1.1c - English DOS Floppy
 	{
 		{
 			"pn",
@@ -111,7 +111,7 @@
 
 		GType_PN,
 		GID_PN,
-		GF_OLD_BUNDLE | GF_CRUNCHED | GF_PLANAR
+		GF_OLD_BUNDLE | GF_CRUNCHED | GF_EGA | GF_PLANAR
 	},
 
 	// Elvira 1 - English Amiga Floppy Demo
@@ -92,7 +92,7 @@
 	},
 
-	// Personal Nightmare 1.1c - English DOS Floppy
+	// Personal Nightmare 1.1c - EGA English DOS Floppy
 	{
 		{

Modified: scummvm/trunk/engines/agos/intern.h
===================================================================